==> org.eclipse.jubula.rc.common.source_2.1.1.201309020759.jar: org/eclipse/jubula/rc/common/commands/ConnectToClientCommand.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.rc.common.commands;

import java.net.UnknownHostException;

import org.eclipse.jubula.communication.ICommand;
import org.eclipse.jubula.communication.message.ConnectToClientMessage;
import org.eclipse.jubula.communication.message.Message;
import org.eclipse.jubula.rc.common.AUTServer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * @author BREDEX GmbH
 * @created Mar 22, 2010
 */
public class ConnectToClientCommand implements ICommand {

    /** the logger */
    private static final Logger LOG = 
        LoggerFactory.getLogger(ConnectToClientCommand.class);

    /** the message */
    private ConnectToClientMessage m_message;
    
    /**
     * {@inheritDoc}
     */
    public Message execute() {
        try {
            AUTServer.getInstance().initClientCommunication(
                    m_message.getClientHostName(), 
                    m_message.getClientPort());
        } catch (UnknownHostException uhe) {
            LOG.error("Error while attempting to connect to client.", uhe); //$NON-NLS-1$
        }
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public Message getMessage() {
        return m_message;
    }

    /**
     * {@inheritDoc}
     */
    public void setMessage(Message message) {
        m_message = (ConnectToClientMessage)message;
    }

    /**
     * {@inheritDoc}
     */
    public void timeout() {
        LOG.error(this.getClass().getName() + ".timeout() called"); //$NON-NLS-1$
    }

}

==> org.eclipse.jubula.rc.common.source_3.1.0.201506041311.jar: org/eclipse/jubula/rc/common/commands/ConnectToClientCommand.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2010 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.rc.common.commands;

import java.net.UnknownHostException;

import org.eclipse.jubula.communication.internal.ICommand;
import org.eclipse.jubula.communication.internal.message.ConnectToClientMessage;
import org.eclipse.jubula.communication.internal.message.Message;
import org.eclipse.jubula.rc.common.AUTServer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * @author BREDEX GmbH
 * @created Mar 22, 2010
 */
public class ConnectToClientCommand implements ICommand {

    /** the logger */
    private static final Logger LOG = 
        LoggerFactory.getLogger(ConnectToClientCommand.class);

    /** the message */
    private ConnectToClientMessage m_message;
    
    /**
     * {@inheritDoc}
     */
    public Message execute() {
        try {
            AUTServer.getInstance().initClientCommunication(
                    m_message.getClientHostName(), 
                    m_message.getClientPort());
        } catch (UnknownHostException uhe) {
            LOG.error("Error while attempting to connect to client.", uhe); //$NON-NLS-1$
        }
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public Message getMessage() {
        return m_message;
    }

    /**
     * {@inheritDoc}
     */
    public void setMessage(Message message) {
        m_message = (ConnectToClientMessage)message;
    }

    /**
     * {@inheritDoc}
     */
    public void timeout() {
        LOG.error(this.getClass().getName() + ".timeout() called"); //$NON-NLS-1$
    }

}
